<?php

namespace App\Model;

use Nette;

class AdminModel {

    private $db = null;

    public function __construct($db) {
        $this->db = $db;
    }

    /** Vrátí všechny názvy a id technologií
     * @return array of objects
     */
    public function getTechnologies() {
        $stmt = $this->db->query("SELECT technology_id, name "
                . "FROM recording_technologies");
        return $stmt->fetchAll();
    }
    
        public function getServices() {
        $stmt = $this->db->query("SELECT service_id, service_name "
                . "FROM services");
        return $stmt->fetchAll();
    }
    
    public function getPrices() {
        $stmt = $this->db->query("SELECT service_name, cost, price_from, price_till "
                . " FROM prices "
                . " JOIN services USING (service_id)"
                . " ORDER BY price_id DESC");
        return $stmt->fetchAll();
    }
    

    /** Funkce k přidání technologie do databáze 
     *  @param object $values Pole hodnot názvů nahrávacích technologií
     */
    public function addTechnology($values) {
        $this->db->query("INSERT INTO recording_technologies(name) "
                . "VALUES (?)", $values['name']);
    }

    /** Funkce ke smazání technologie z databáze 
     * @param object $techId Pole hodnot názvů nahrávacích technologií
     */ 
    public function deleteTechnology($techId) {
        $this->db->query("DELETE FROM recording_technologies "
                . "WHERE technology_id = ?", $techId['technologies']);
    }
    
    /** Funkce k přidání ceny 
     * @param object $values Pole hodnot cen
     */
    public function addPrices($values) {
         try {
            $this->db->beginTransaction();
            
            $service = null;                    
            $stmt = $this->db->query("SELECT * FROM prices "                                 
                    . " WHERE service_id = ? AND "
                    . " (? BETWEEN prices.price_from AND prices.price_till)", $values['service_id'], $values['price_from'] );          
           
            $service = $stmt->fetch(); 
            
            if(!is_null($service)) {
               $date = \date('Y-m-d');
               $this->db->query("UPDATE prices "
                       . " SET price_till = ?"
                       . " WHERE price_id = ?", $date, $service['price_id']);
            } 
            
           
            
            $stmt = $this->db->query("INSERT INTO prices(service_id, price_from, price_till, cost)"
                . "VALUES (?,?,?,?)", $values['service_id'], $values['price_from'], $values['price_till'], $values['cost']);
            
           $this->db->commit(); 
            
        } catch (Nette\Neon\Exception $e) {
            $this->db->rollBack();
            return false;
        }
        
    }
    
     public function getAllOrders() {
        $stmt = $this->db->query("SELECT users.user_id, users.name, users.surname, order_id, 
            order_date, order_status, record_term, total_price 
            FROM orders 
            JOIN users USING (user_id)
            ORDER BY order_date DESC");
        return $stmt->fetchAll();
    }

}
