<?php

namespace App\Model;

use Nette;

class EciovniModel {

    private $db = null;

    public function __construct($db) {
        $this->db = $db;
    }

     /** Vrací adresu daného uživatele
     * @param int $id ID uživatele 
     * @return object
     */
    public function getAddress($id) {
        $stmt = $this->db->query("SELECT * FROM addresses"
                . " JOIN countries USING (country_id)"
                . " WHERE address_id = ?", $id);
        return $stmt->fetch();
    }

     /** Vrací objednávku daného uživatele
     * @param int $id ID uživatele 
     * @return object
     */
    public function getOrder($id) {
        $stmt = $this->db->query("SELECT order_id, record_term, order_date, 
                total_price, recording_technologies.name AS technologyName, hours
                FROM orders 
                JOIN order_items USING (order_id)
                JOIN recording_technologies USING (technology_id)
                WHERE order_id = ?", (int) $id);
        return $stmt->fetch();
    }

     /** Vrací všechny objednané hudební nástroje z objednávky
     * @param int $id ID objednávky
     * @return array of objects
     */
    public function getInstruments($id) {
        $stmt = $this->db->query("SELECT instruments.name AS instrumentName, order_instruments.counts, prices.cost AS profit
            FROM orders 
            JOIN order_instruments USING (order_id)
            JOIN instruments USING (instrument_id)
            JOIN instrument_counts USING (instrument_id)     
            JOIN order_items USING (order_id)
            JOIN services USING (service_id)  
            JOIN prices USING (service_id)
            WHERE order_id = ? AND service_id = 7 AND (orders.order_date BETWEEN prices.price_from AND prices.price_till)
            GROUP BY instrumentName", (int) $id);
        return $stmt->fetchAll();
    }

    /** Vrací všechny objednané služby z objednávky
     * @param int $id ID objednávky
     * @return array of objects
     */
    public function getServices($id) {
        $orderId = (int) $id;
        $stmt = $this->db->query("SELECT service_name, prices.cost AS profit, orders.order_date 
            FROM orders
            JOIN order_items USING (order_id)
            JOIN services USING (service_id)
            JOIN prices USING (service_id)
            WHERE order_id = ?  
            AND NOT (service_id = 7 OR service_id = 9 OR service_id = 10) 
            AND (orders.order_date BETWEEN prices.price_from AND prices.price_till)", $orderId);
        return $stmt->fetchAll();
    }

}
