<?php

namespace App\Presenters;

use Nette;
use App\Model,
    Nette\Application\UI,
    App\Forms\SignFormFactory;
    
/**
 * Description of AdminPresenter
 *
 * @author Mářa
 */
class AdminPresenter extends BasePresenter {

    private $model = null;

    private function getModel() {
        if (!isset($this->model)) {
            $this->model = new Model\AdminModel($this->context->getService("database"));
        }
        return $this->model;
    }

    public function renderDefault() {
        $this->template->anyVariable = 'any value';
    }

    public function createComponentAddTechnologyForm() {
        $form = new UI\Form;
        $form->addText('name', 'Technology name:');
        $form->addSubmit('add', 'Add technology');
        $form->onSuccess[] = array($this, 'addTechnologyFormSucceeded');
        return $form;
    }

    public function createComponentDeleteTechnologyForm() {
        $form = new UI\Form;
        $technology = $this->getModel()->getTechnologies();
        $technologyArray = array();
        foreach ($technology as $t) {
            $technologyArray[$t['technology_id']] = $t['name'];
        }
        $form->addSelect('technologies', 'Choose technology:')
                ->setItems($technologyArray);

        $form->addSubmit('delete', 'Delete technology');
        $form->onSuccess[] = array($this, 'deleteTechnologyFormSucceeded');
        return $form;
    }

    public function addTechnologyFormSucceeded(UI\Form $form, $values) {
        $this->getModel()->addTechnology($values);
        $this->redirect('Admin:editService');
    }

    public function deleteTechnologyFormSucceeded(UI\Form $form, $techId) {
        $this->getModel()->deleteTechnology($techId);
        $this->redirect('Admin:editService');
    }

    public function createComponentAddPricesForm() {
        $form = new UI\Form;

        $service = $this->getModel()->getServices();
        $serviceArray = array();
        foreach ($service as $s) {
            $serviceArray[$s['service_id']] = $s['service_name'];
        }

        $form->addSelect('service_id', 'Choose service name:')
                ->setItems($serviceArray);

        $form->addText('cost', 'Cost:')
                ->addRule(UI\Form::INTEGER, 'Cost must be number');
          
        $form->addDatePicker('price_from', 'Valid from:')
                ->addRule(\Nette\Forms\Form::RANGE, 'Date must be in the future',
                    array(new \Nette\Utils\DateTime('tomorrow'), null));
        
        $form->addDatePicker('price_till', 'Valid until:')
                     ->addRule(\Nette\Forms\Form::RANGE, 'Date must be in the future',
                    array(new \Nette\Utils\DateTime('tomorrow'), null));
        $form->addSubmit('add', 'Add price');
        $form->onSuccess[] = array($this, 'addPricesFormSucceeded');
        return $form;
    }

    public function addPricesFormSucceeded(UI\Form $form, $values) {
        $this->getModel()->addPrices($values);
        $this->redirect('Info:profile');
    }
    
    public function actionEditPrices(){
         $this->template->prices = $this->getModel()->getPrices();
    }
    
    public function actionViewOrders(){
      $this->template->allorders = $this->getModel()->getAllOrders();
    }

}
