<?php

namespace App\Presenters;

use Nette;
use App\Model;
use Nette\Application\UI;
use Nette\Application\BadRequestException;

class InfoPresenter extends BasePresenter {

    private $model = null;

    private function getModel() {
        if (!isset($this->model)) {
            $this->model = new Model\DatabazeModel($this->context->getService("database"));
        }
        return $this->model;
    }

    public function renderDefault() {
        $this->template->anyVariable = 'any value';
    }

    public function actionProfile() {
        $this->template->profile = $this->getModel()->getUsers($this->getUser()->getId());
        
        if($this->user->isInRole('admin')){                
                $this->template->authorization = true;
            }else{
                $this->template->authorization = false;
            } 
    }
    
    public function createComponentEditProfileForm() {
        $user = $this->getModel()->getUsers($this->getUser()->getId());
        $countries = $this->getModel()->getCountries();
        $countriesArray = array();
        foreach ($countries as $c) {
            array_push($countriesArray, $c['country_name']);
        }
        $form = new UI\Form;
        $form->addText('name', 'First name:')->setRequired('placeholder', 'Enter your name')
                ->setDefaultValue($user->name);
        $form->addText('surname', 'Last name:')
                ->setRequired('Enter your last name')
                ->setDefaultValue($user->surname);
        $form->addText('email', 'E-mail:')
                ->setRequired('Enter your email')
                ->setDefaultValue($user->email);
        $form->addPassword('password', 'Password:')
                ->setRequired('Enter your password')
                ->addRule(UI\Form::MIN_LENGTH, 'Password must have at least 5 characters', 5)
                ->setDefaultValue($user->password);
        $form->addPassword('passwordVerify', 'Check your password:')
                ->setRequired('Re-enter your password to check')
                ->addRule(UI\Form::EQUAL, 'Passwords do not match', $form['password']);               
        $form->addText('company_name', 'Company name:')
                ->setRequired('Enter name of your company')
                ->setDefaultValue($user->company_name);
        $form->addText('vat_id', 'VAT ID:')
                ->setRequired('Enter name of your company')
                ->setDefaultValue($user->vat_id);

        $form->addText('street', 'Street:')
                ->setRequired('Enter your street')
                ->setDefaultValue($user->street);
        $form->addText('city', 'City:')
                ->setRequired('Enter your city')
                ->setDefaultValue($user->city);
        $form->addSelect('country', 'Country:', $countriesArray)
                ->setRequired('Choose your country');           
        $form->addText('zip', 'Zip:')
                ->setRequired('Enter your zip')
                ->setDefaultValue($user->zip);

        $form->addSubmit('edit', 'Save changes');
        $form->onSuccess[] = array($this, 'editProfileFormSucceeded');
        return $form;
    }

    public function editProfileFormSucceeded(UI\Form $form, $values) {
        $this->getModel()->setUsers($values, $this->getUser()->getId());
        $this->flashMessage('Profile updated');
        $this->redirect('Info:profile');
    }

}
