<?php

namespace App\Presenters;

use Nette,
    Nette\Application\UI,
    App\Forms\SignFormFactory,
    App\Model,
    Nette\Mail\Message;

class LoginPresenter extends UI\Presenter {

    private $model = null;

    private function getModel() {
        if (!isset($this->model)) {
            $this->model = new Model\RegistrationModel($this->context->getService("database"));
        }
        return $this->model;
    }

    public function renderDefault() {
        $this->template->anyVariable = 'any value';
    }

    //zaslani noveho hesla
    public function createComponentSendNewPassForm() {
        $form = new UI\Form;
        $form->getElementPrototype()->class('sendPassword');
        $form->addText('email')->setAttribute('placeholder', 'Enter your email')->setRequired();
        $form->addSubmit('send', 'Send');
        $form->onSuccess[] = array($this, 'sendNewPasswordFormSucceeded');
        return $form;
    }

    private function getRandomString() {

        $characters = '0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ';
        $charactersLength = strlen($characters);
        $randomString = '';
        for ($i = 0; $i < 10; $i++) {
            $randomString .= $characters[rand(0, $charactersLength - 1)];
        }
        return $randomString;
    }

    public function sendNewPasswordFormSucceeded(UI\Form $form, $values) {
        $newPassword = $this->getRandomString();
        $mail = new Message;
        $mail->setFrom('Capellen <admin@example.com>')
                ->addTo($values['email'])
                ->setSubject('Password reset')
                ->setBody('Hello,this is your new password: ' . $newPassword);
        $mailer = new Nette\Mail\SmtpMailer(array(
            'host' => 'smtp.gmail.com',
            'username' => 'mariedoruskova123@gmail.com',
            'password' => 'Marrythenight123',
            'secure' => 'ssl',
        ));
        $mailer->send($mail);
        $this->getModel()->updateNewPassword($newPassword, $values['email']);
        $this->redirect('Sign:in');
    }

    protected function createComponentRegistrationForm() {
        $countries = $this->getModel()->getCountries();
        $countriesArray = array();
        foreach ($countries as $c) {
            array_push($countriesArray, $c['country_name']);
        }
        $form = new UI\Form;
        $form->addText('name', 'First name:')->setRequired('Enter your name');
        $form->addText('surname', 'Last name:')
                ->setRequired('Enter your last name');
        $form->addText('email', 'E-mail:')->setRequired('Enter your email');

        $form->addPassword('password', 'Password:')
                ->setRequired('Enter your password')
                ->addRule(UI\Form::MIN_LENGTH, 'Password must have at least 5 characters', 5);

        $form->addPassword('passwordVerify', 'Check your password:')
                ->setRequired('Re-enter your password to check')
                ->addRule(UI\Form::EQUAL, 'Passwords do not match', $form['password']);

        $form->addText('company_name', 'Company name:')
                ->setRequired('Enter name of your company');
        $form->addText('vat_id', 'VAT ID:')
                ->setRequired('Enter name of your company');

        $form->addText('street', 'Street:')->setRequired('Enter your street');
        $form->addText('city', 'City:')->setRequired('Enter your city');
        $form->addSelect('country', 'Country:', $countriesArray)
                ->setRequired('Choose your country');
        $form->addText('zip', 'Zip:')->setRequired('Enter your zip');

        $form->addSubmit('login', 'Register');
        $form->onSuccess[] = array($this, 'registrationFormSucceeded');
        return $form;
    }

    public function registrationFormSucceeded(UI\Form $form, $values) {          
        $values = $form->getValues(TRUE);
        $template = $this->createTemplate();
        $template->setFile(__DIR__ . '/templates/Login/registrationemail.latte');       
        $template->values = $values;
        
        $mail = new Message;
        $mail->setFrom('Capellen <admin@example.com>')
                ->addTo($values['email'])
                ->setSubject('Registration form')                
                ->setHtmlBody($template);
               
        $mailer = new Nette\Mail\SmtpMailer(array(
            'host' => 'smtp.gmail.com',
            'username' => 'mariedoruskova123@gmail.com',
            'password' => 'Marrythenight123',
            'secure' => 'ssl',
        ));
        $mailer->send($mail);
        $this->getModel()->addUser($values);
        $this->redirect('Sign:in');
    }

}
