<?php

namespace App\Presenters;

use Nette,
    Nette\Application\UI,
    App\Model,
    Nette\Mail\Message;

class OrderPresenter extends BasePresenter {

    private $model = null;

    private function getModel() {
        if (!isset($this->model)) {
            $this->model = new Model\OrderModel($this->context->getService("database"));
        }
        return $this->model;
    }

    public function renderDefault() {
        $this->template->anyVariable = 'any value';
    }
        
    public function actionMyorders(){
      $this->template->myorder = $this->getModel()->getOrders($this->getUser()->getId());
    }       
    
    public function actionOrderconfirm($id){
        $this->template->orderId = $id;
    }
      
    public function createComponentNewOrderForm() {        
        $hoursArray = array(
            1,2,3,4
        );
        
        $form = new UI\Form;       
        $form->addSelect('hours', 'Hours:')
                ->setItems($hoursArray, false)
                ->setRequired('Enter number of hours.');

        $form->getElementPrototype()->addAttributes(array('class' => 'ma-pekna-trida'));

        //**instruments - asociative array
        $instrument = $this->getModel()->getInstruments();
        $vysledek = array();
        foreach ($instrument as $radek) {
            $obj = array(
                'name' => $radek['name'],
                'values' => [],
                'label' => $radek['label'],
                'instrument_id' => $radek['instrument_id']
            );
            $vysledek[$radek['instrument_id']] = $obj;
        }

        foreach ($instrument as $radek) {
           $vysledek[$radek['instrument_id']]['values'][$radek['value']] = $radek['value'];
        }
        foreach ($vysledek as $select) {
            $form->addSelect($select['name'], $select['label'], $select['values']);
        }

        //** services
        $service = $this->getModel()->getServices();
        $serviceArray = array();
        foreach ($service as $radek) {
            $obj = array(
                'name' => $radek['service_name'],
                'label' => $radek['label'],
                'service_id' => $radek['service_id']
            );
            array_push($serviceArray, $obj);
        }

        foreach ($serviceArray as $check) {
            $form->addCheckbox($check['name'], $check['label']);
        }
       
        //**Recording technology**//
        $technology = $this->getModel()->getTechnologies();
        $technologyArray = array();
        foreach ($technology as $t) {
            $technologyArray[$t['technology_id']] = $t['name'];
        }
                   
        $form->addSelect('technology', 'Recording technology:')->setItems($technologyArray);

        //**Record Term**//
        $form->addDatePicker('date', 'Record term:')
                 ->addRule(\Nette\Forms\Form::RANGE, 'Date must be in the future',
                    array(new \Nette\Utils\DateTime('today'), null));
         

        //**Total cost - payment**//
        $form->addSubmit('send', 'Send order')->setAttribute('id', 'orderSend');

        $form->onSuccess[] = array($this, 'newOrderFormSucceeded');
        return $form;
    }

    public function newOrderFormSucceeded(UI\Form $form, $values) {
        $val = $form->getValues(TRUE);
        $userMail = $this->getModel()->getEmail($this->getUser()->getId());
        $template = $this->createTemplate();
        $template->setFile(__DIR__ . '/templates/Order/orderconfirmemail.latte');       
        $template->val = $val;
        
        $mail = new Message;
        $mail->setFrom('Capellen <admin@example.com>')
                ->addTo($userMail['email'])
                ->setSubject('Confirm order form')                
                ->setHtmlBody($template);
               
        $mailer = new Nette\Mail\SmtpMailer(array(
            'host' => 'smtp.gmail.com',
            'username' => 'mariedoruskova123@gmail.com',
            'password' => 'Marrythenight123',
            'secure' => 'ssl',
        ));
        $mailer->send($mail);

        $lastId = $this->getModel()->calculateOrder($values, $this->getUser()->getId());       
        $this->redirect('Order:orderconfirm', $lastId);
    }
   
 
   
}
